@@ -1,5 +1,5 @@
 /* GSK - The GTK Scene Kit
- * Copyright 2016  Endless 
+ * Copyright 2016  Endless
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,11 +49,50 @@
  * @GSK_BLUR_NODE: A node that applies a blur
  * @GSK_DEBUG_NODE: Debug information that does not affect the rendering
  * @GSK_GL_SHADER_NODE: A node that uses OpenGL fragment shaders to render
- * @GSK_TEXTURE_SCALE_NODE: A node drawing a `GdkTexture` scaled and filtered (Since: 4.10)
- * @GSK_MASK_NODE: A node that masks one child with another (Since: 4.10)
- 
+ *
  * The type of a node determines what the node is rendering.
  */
+
+/**
+ * GSK_TEXTURE_SCALE_NODE:
+ *
+ * A node drawing a `GdkTexture` scaled and filtered.
+ *
+ * Since: 4.10
+ */
+
+/**
+ * GSK_MASK_NODE:
+ *
+ * A node that masks one child with another.
+ *
+ * Since: 4.10
+ */
+
+/**
+ * GSK_STROKE_NODE:
+ *
+ * A node that strokes a path.
+ *
+ * Since: 4.14
+ */
+
+/**
+ * GSK_FILL_NODE:
+ *
+ * A node that fills a path.
+ *
+ * Since: 4.14
+ */
+
+/**
+ * GSK_SUBSURFACE_NODE:
+ *
+ * A node that possibly redirects part of the scene graph to a subsurface.
+ *
+ * Since: 4.14
+ */
+
 typedef enum {
   GSK_NOT_A_RENDER_NODE = 0,
   GSK_CONTAINER_NODE,
@@ -82,7 +121,10 @@ typedef enum {
   GSK_DEBUG_NODE,
   GSK_GL_SHADER_NODE,
   GSK_TEXTURE_SCALE_NODE,
-  GSK_MASK_NODE
+  GSK_MASK_NODE,
+  GSK_FILL_NODE,
+  GSK_STROKE_NODE,
+  GSK_SUBSURFACE_NODE,
 } GskRenderNodeType;
 
 /**
@@ -170,6 +212,163 @@ typedef enum {
   GSK_CORNER_BOTTOM_LEFT
 } GskCorner;
 
+/**
+ * GskFillRule:
+ * @GSK_FILL_RULE_WINDING: If the path crosses the ray from
+ *   left-to-right, counts +1. If the path crosses the ray
+ *   from right to left, counts -1. (Left and right are determined
+ *   from the perspective of looking along the ray from the starting
+ *   point.) If the total count is non-zero, the point will be filled.
+ * @GSK_FILL_RULE_EVEN_ODD: Counts the total number of
+ *   intersections, without regard to the orientation of the contour. If
+ *   the total number of intersections is odd, the point will be
+ *   filled.
+ *
+ * Specifies how paths are filled.
+ *
+ * Whether or not a point is included in the fill is determined by taking
+ * a ray from that point to infinity and looking at intersections with the
+ * path. The ray can be in any direction, as long as it doesn't pass through
+ * the end point of a segment or have a tricky intersection such as
+ * intersecting tangent to the path.
+ *
+ * (Note that filling is not actually implemented in this way. This
+ * is just a description of the rule that is applied.)
+ *
+ * New entries may be added in future versions.
+ *
+ * Since: 4.14
+ */
+typedef enum {
+  GSK_FILL_RULE_WINDING,
+  GSK_FILL_RULE_EVEN_ODD
+} GskFillRule;
+
+/**
+ * GskLineCap:
+ * @GSK_LINE_CAP_BUTT: Start and stop the line exactly at the start
+ *   and end point
+ * @GSK_LINE_CAP_ROUND: Use a round ending, the center of the circle
+ *   is the start or end point
+ * @GSK_LINE_CAP_SQUARE: use squared ending, the center of the square
+ *   is the start or end point
+ *
+ * Specifies how to render the start and end points of contours or
+ * dashes when stroking.
+ *
+ * The default line cap style is `GSK_LINE_CAP_BUTT`.
+ *
+ * New entries may be added in future versions.
+ *
+ * <figure>
+ *   <picture>
+ *     <source srcset="caps-dark.png" media="(prefers-color-scheme: dark)">
+ *     <img alt="Line Cap Styles" src="caps-light.png">
+ *   </picture>
+ *   <figcaption>GSK_LINE_CAP_BUTT, GSK_LINE_CAP_ROUND, GSK_LINE_CAP_SQUARE</figcaption>
+ * </figure>
+ *
+ * Since: 4.14
+ */
+typedef enum {
+  GSK_LINE_CAP_BUTT,
+  GSK_LINE_CAP_ROUND,
+  GSK_LINE_CAP_SQUARE
+} GskLineCap;
+
+/**
+ * GskLineJoin:
+ * @GSK_LINE_JOIN_MITER: Use a sharp angled corner
+ * @GSK_LINE_JOIN_ROUND: Use a round join, the center of the circle is
+ *   the join point
+ * @GSK_LINE_JOIN_BEVEL: use a cut-off join, the join is cut off at half
+ *   the line width from the joint point
+ *
+ * Specifies how to render the junction of two lines when stroking.
+ *
+ * The default line join style is `GSK_LINE_JOIN_MITER`.
+ *
+ * New entries may be added in future versions.
+ *
+ * <figure>
+ *   <picture>
+ *     <source srcset="join-dark.png" media="(prefers-color-scheme: dark)">
+ *     <img alt="Line Join Styles" src="join-light.png">
+ *   </picture>
+ *   <figcaption>GSK_LINE_JOINT_MITER, GSK_LINE_JOINT_ROUND, GSK_LINE_JOIN_BEVEL</figcaption>
+ * </figure>
+ *
+ * Since: 4.14
+ */
+typedef enum {
+  GSK_LINE_JOIN_MITER,
+  GSK_LINE_JOIN_ROUND,
+  GSK_LINE_JOIN_BEVEL,
+} GskLineJoin;
+
+/**
+ * GskPathOperation:
+ * @GSK_PATH_MOVE: A move-to operation, with 1 point describing the target point.
+ * @GSK_PATH_CLOSE: A close operation ending the current contour with a line back
+ *   to the starting point. Two points describe the start and end of the line.
+ * @GSK_PATH_LINE: A line-to operation, with 2 points describing the start and
+ *   end point of a straight line.
+ * @GSK_PATH_QUAD: A curve-to operation describing a quadratic Bézier curve
+ *   with 3 points describing the start point, the control point and the end
+ *   point of the curve.
+ * @GSK_PATH_CUBIC: A curve-to operation describing a cubic Bézier curve with 4
+ *   points describing the start point, the two control points and the end point
+ *   of the curve.
+ * @GSK_PATH_CONIC: A rational quadratic Bézier curve with 3 points describing
+ *   the start point, control point and end point of the curve. A weight for the
+ *   curve will be passed, too.
+ *
+ * Describes the segments of a `GskPath`.
+ *
+ * More values may be added in the future.
+ *
+ * Since: 4.14
+ */
+typedef enum {
+  GSK_PATH_MOVE,
+  GSK_PATH_CLOSE,
+  GSK_PATH_LINE,
+  GSK_PATH_QUAD,
+  GSK_PATH_CUBIC,
+  GSK_PATH_CONIC,
+} GskPathOperation;
+
+/**
+ * GskPathDirection:
+ * @GSK_PATH_FROM_START: The tangent in path direction of the incoming side
+ *   of the path
+ * @GSK_PATH_TO_START: The tangent against path direction of the incoming side
+ *   of the path
+ * @GSK_PATH_TO_END: The tangent in path direction of the outgoing side
+ *   of the path
+ * @GSK_PATH_FROM_END: The tangent against path direction of the outgoing
+ *   side of the path
+ *
+ * Used to pick one of the four tangents at a given point on the path.
+ *
+ * Note that the directions for @GSK_PATH_FROM_START/@GSK_PATH_TO_END and
+ * @GSK_PATH_TO_START/@GSK_PATH_FROM_END will coincide for smooth points.
+ * Only sharp turns will exhibit four different directions.
+ *
+ * <picture>
+ *   <source srcset="directions-dark.png" media="(prefers-color-scheme: dark)">
+ *   <img alt="Path Tangents" src="directions-light.png">
+ * </picture>
+ *
+ * Since: 4.14
+ */
+typedef enum {
+  GSK_PATH_FROM_START,
+  GSK_PATH_TO_START,
+  GSK_PATH_TO_END,
+  GSK_PATH_FROM_END,
+} GskPathDirection;
+
 /**
  * GskSerializationError:
  * @GSK_SERIALIZATION_UNSUPPORTED_FORMAT: The format can not be identified
@@ -236,11 +435,12 @@ typedef enum
  * @GSK_GL_UNIFORM_TYPE_VEC3: A GLSL vec3 / graphene_vec3_t uniform
  * @GSK_GL_UNIFORM_TYPE_VEC4: A GLSL vec4 / graphene_vec4_t uniform
  *
- * This defines the types of the uniforms that `GskGLShaders`
- * declare.
+ * Defines the types of the uniforms that `GskGLShaders` declare.
  *
  * It defines both what the type is called in the GLSL shader
  * code, and what the corresponding C type is on the Gtk side.
+ *
+ * Deprecated: 4.16
  */
 typedef enum
 {
@@ -274,4 +474,3 @@ typedef enum
   GSK_MASK_MODE_LUMINANCE,
   GSK_MASK_MODE_INVERTED_LUMINANCE
 } GskMaskMode;
-
