@@ -17,8 +17,7 @@
  * Authors: Benjamin Otte <otte@gnome.org>
  */
 
-#ifndef __GTK_COLUMN_VIEW_COLUMN_H__
-#define __GTK_COLUMN_VIEW_COLUMN_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
@@ -95,8 +94,13 @@ GDK_AVAILABLE_IN_ALL
 void                    gtk_column_view_column_set_expand               (GtkColumnViewColumn    *self,
                                                                          gboolean                expand);
 GDK_AVAILABLE_IN_ALL
-gboolean                gtk_column_view_column_get_expand            (GtkColumnViewColumn    *self);
+gboolean                gtk_column_view_column_get_expand               (GtkColumnViewColumn    *self);
+
+GDK_AVAILABLE_IN_4_10
+void                    gtk_column_view_column_set_id                   (GtkColumnViewColumn    *self,
+                                                                         const char             *id);
+GDK_AVAILABLE_IN_4_10
+const char *            gtk_column_view_column_get_id                   (GtkColumnViewColumn    *self);
 
 G_END_DECLS
 
-#endif  /* __GTK_COLUMN_VIEW_COLUMN_H__ */
