@@ -52,7 +52,6 @@ G_BEGIN_DECLS
  * @GTK_DEBUG_CONSTRAINTS: Information from the constraints solver
  * @GTK_DEBUG_BUILDER_OBJECTS: Log unused GtkBuilder objects
  * @GTK_DEBUG_A11Y: Information about accessibility state changes
- * @GTK_DEBUG_ICONFALLBACK: Information about icon fallback. Since: 4.2
  *
  * Flags to use with gtk_set_debug_flags().
  *
@@ -60,6 +59,30 @@ G_BEGIN_DECLS
  * types of debugging information. Some of these flags are
  * only available when GTK has been configured with `-Ddebug=true`.
  */
+
+/**
+ * GTK_DEBUG_ICONFALLBACK:
+ *
+ * Information about icon fallback.
+ *
+ * Since: 4.2
+ */
+
+/**
+ * GTK_DEBUG_INVERT_TEXT_DIR:
+ *
+ * Inverts the default text-direction.
+ *
+ * Since: 4.8
+ */
+
+/**
+ * GTK_DEBUG_CSS:
+ *
+ * Information about deprecated CSS features.
+ *
+ * Since: 4.16
+ */
 typedef enum {
   GTK_DEBUG_TEXT            = 1 <<  0,
   GTK_DEBUG_TREE            = 1 <<  1,
@@ -68,7 +91,7 @@ typedef enum {
   GTK_DEBUG_GEOMETRY        = 1 <<  4,
   GTK_DEBUG_ICONTHEME       = 1 <<  5,
   GTK_DEBUG_PRINTING        = 1 <<  6,
-  GTK_DEBUG_BUILDER         = 1 <<  7,
+  GTK_DEBUG_BUILDER_TRACE   = 1 <<  7,
   GTK_DEBUG_SIZE_REQUEST    = 1 <<  8,
   GTK_DEBUG_NO_CSS_CACHE    = 1 <<  9,
   GTK_DEBUG_INTERACTIVE     = 1 << 10,
@@ -80,18 +103,18 @@ typedef enum {
   GTK_DEBUG_A11Y            = 1 << 17,
   GTK_DEBUG_ICONFALLBACK    = 1 << 18,
   GTK_DEBUG_INVERT_TEXT_DIR = 1 << 19,
+  GTK_DEBUG_CSS             = 1 << 20,
+  GTK_DEBUG_BUILDER         = 1 << 21,
 } GtkDebugFlags;
 
-#ifdef G_ENABLE_DEBUG
-
+/**
+ * GTK_DEBUG_CHECK:
+ * @type: type to check
+ *
+ * Whether the `type` debug flag is set.
+ **/
 #define GTK_DEBUG_CHECK(type) G_UNLIKELY (gtk_get_debug_flags () & GTK_DEBUG_##type)
 
-#else /* !G_ENABLE_DEBUG */
-
-#define GTK_DEBUG_CHECK(type) 0
-
-#endif /* G_ENABLE_DEBUG */
-
 GDK_AVAILABLE_IN_ALL
 GtkDebugFlags gtk_get_debug_flags (void);
 GDK_AVAILABLE_IN_ALL
